@@ -112,8 +112,9 @@
 #'
 #'# Load package
 #'   library(lpirfs)
-#'   library(ggpubr)
 #'   library(gridExtra)
+#'   library(ggpubr)
+#'
 #'
 #'# Load (endogenous) data
 #'   endog_data <- interest_rules_var_data
@@ -139,11 +140,11 @@
 #'  plot(results_nl)
 #'
 #'# Make and save all plots
-#'   nl_plots <- plot_nl(results_nl)
+#'  nl_plots <- plot_nl(results_nl)
 #'
 #'# Save plots based on states
-#'   s1_plots <- sapply(nl_plots$gg_s1, ggplotGrob)
-#'   s2_plots <- sapply(nl_plots$gg_s2, ggplotGrob)
+#'  s1_plots <- sapply(nl_plots$gg_s1, ggplotGrob)
+#'  s2_plots <- sapply(nl_plots$gg_s2, ggplotGrob)
 #'
 #'# Show first irf of each state
 #'   plot(s1_plots[[1]])
@@ -156,7 +157,7 @@
 #'                      ## Example with exogenous variables ##
 #'
 #'# Load (endogenous) data
-#'   endog_data <- interest_rules_var_data
+#'  endog_data <- interest_rules_var_data
 #'
 #'# Choose data for switching variable (here Federal Funds Rate)
 #'# Important: The switching variable does not have to be used within the VAR!
@@ -292,11 +293,6 @@ lp_nl <- function(endog_data,
     stop('Please specify lambda for the HP-filter.')
   }
 
-  # Check whether 'gamma' is given
-  if(isTRUE(specs$use_logistic) & is.null(specs$gamma)){
-    stop('Please specify gamma for the transition function.')
-  }
-
   # Check whether 'confint' is given
   if(is.null(specs$confint)){
     stop('Please specify a value for the width of the confidence bands.')
@@ -613,7 +609,7 @@ lp_nl <- function(endog_data,
 
   # Make matrix to store selected lags
   chosen_lags_k             <- matrix(NaN, specs$endog,  1)
-  names(diagnost_each_k)    <- specs$column_names
+  # names(diagnost_each_k)    <- specs$column_names
 
  # --- Loops to estimate local projections.
   nl_irfs <- foreach(s         = 1:specs$endog,
@@ -690,13 +686,13 @@ lp_nl <- function(endog_data,
               irf_temp_s2_up[,   h + 1] <- t(b1_up_s2     %*%  d[ , s])
 
               # Save full summary matrix in list for each horizon
-              diagnost_ols_each_h[[h]]             <- diagnost_each_k
+              diagnost_ols_each_h[[h]]        <- diagnost_each_k
               chosen_lags[[h]]                <- chosen_lags_k
          }
 
          # Give names to horizon
-           names(diagnost_ols_each_h)    <- paste("h", 1:specs$hor, sep = " ")
-           names(chosen_lags)            <- paste("h", 1:specs$hor, sep = " ")
+         #  names(diagnost_ols_each_h)    <- paste("h", 1:specs$hor, sep = " ")
+         #  names(chosen_lags)            <- paste("h", 1:specs$hor, sep = " ")
 
           list(irf_temp_s1_mean, irf_temp_s1_low, irf_temp_s1_up,
                irf_temp_s2_mean, irf_temp_s2_low, irf_temp_s2_up,
@@ -731,8 +727,8 @@ lp_nl <- function(endog_data,
 
 
    # Fill list with all OLS diagnostics
-   diagnostic_list[[i]]        <- nl_irfs[[i]][7]
-   chosen_lags_list[[i]]       <- nl_irfs[[i]][8]
+   diagnostic_list[[i]]        <- nl_irfs[[i]][[7]]
+   chosen_lags_list[[i]]       <- nl_irfs[[i]][[8]]
 
   }
 
